@@ -1,6 +1,6 @@
 test.max_eigen <- function()
 {
-  en <- create(Ensemble, 50, create(WishartModel, 50, 200))
+  en <- Ensemble(50, WishartModel(50, 200))
   mx <- max_eigen(en)
   theo <- qmp(1, svr=4, var=1)
   cat("\ntheoretical cutoff:",theo,"\n")
